@@ -15,7 +15,7 @@ int get_tty_size(int fd, int *x, int *y)
 
     if (!isatty(fd))
         return 0;
-    if (!ioctl(1,TIOCGWINSZ,&ts) && ts.ws_row>0 && ts.ws_col>0)
+    if (!ioctl(fd,TIOCGWINSZ,&ts) && ts.ws_row>0 && ts.ws_col>0)
     {
         *x=ts.ws_col;
         *y=ts.ws_row;
